**********
Algorithms
**********

.. automodule:: toponetx.algorithms.components
    :members:

.. automodule:: toponetx.algorithms.distance_measures
    :members:

.. automodule:: toponetx.algorithms.distance
    :members:

.. automodule:: toponetx.algorithms.spectrum
    :members: